@@ -1,7 +1,7 @@
 import sys
 
 import pkg_resources
-from coleo import auto_cli
+from coleo import run_cli
 
 from .utils import PaperoniError
 
@@ -11,7 +11,7 @@ def main():
     for entry_point in pkg_resources.iter_entry_points("paperoni.command"):
         commands[entry_point.name] = entry_point.load()
     try:
-        auto_cli(commands, expand="@", print_result=False)
+        run_cli(commands, expand="@")
     except PaperoniError as err:
         print(f"{type(err).__name__}:", err.args[0], file=sys.stderr)
         sys.exit(1)
